@@ -1,6 +1,6 @@
 package Langertha::Engine::Mistral;
 # ABSTRACT: Mistral API
-our $VERSION = '0.202';
+our $VERSION = '0.300';
 use Moose;
 use Carp qw( croak );
 
@@ -11,10 +11,9 @@ extends 'Langertha::Engine::OpenAIBase';
 with 'Langertha::Role::'.$_ for (qw(
   ResponseFormat
   Embedding
+  Tools
 ));
 
-with 'Langertha::Role::Tools';
-
 
 has '+url' => (
   lazy => 1,
@@ -29,6 +28,11 @@ sub _build_api_key {
 
 sub openapi_file { yaml => dist_file('Langertha','mistral.yaml') };
 
+sub _build_openapi_operations {
+  require Langertha::Spec::Mistral;
+  return Langertha::Spec::Mistral::data();
+}
+
 sub default_model { 'mistral-small-latest' }
 
 sub chat_operation_id { 'chat_completion_v1_chat_completions_post' }
@@ -52,7 +56,7 @@ Langertha::Engine::Mistral - Mistral API
 
 =head1 VERSION
 
-version 0.202
+version 0.300
 
 =head1 SYNOPSIS
 
