@@ -1,6 +1,6 @@
 package Langertha::Engine::OpenAI;
 # ABSTRACT: OpenAI API
-our $VERSION = '0.202';
+our $VERSION = '0.300';
 use Moose;
 use Carp qw( croak );
 
@@ -10,10 +10,10 @@ with 'Langertha::Role::'.$_ for (qw(
   ResponseFormat
   Embedding
   Transcription
+  ImageGeneration
+  Tools
 ));
 
-with 'Langertha::Role::Tools';
-
 
 has compatibility_for_engine => (
   is => 'ro',
@@ -51,7 +51,7 @@ Langertha::Engine::OpenAI - OpenAI API
 
 =head1 VERSION
 
-version 0.202
+version 0.300
 
 =head1 SYNOPSIS
 
