@@ -1,9 +1,10 @@
 package Langertha::Role::Chat;
 # ABSTRACT: Role for APIs with normal chat functionality
-our $VERSION = '0.202';
+our $VERSION = '0.300';
 use Moose::Role;
 use Future::AsyncAwait;
 use Carp qw( croak );
+use Log::Any qw( $log );
 
 requires qw(
   chat_request
@@ -46,6 +47,8 @@ sub chat_messages {
 
 sub simple_chat {
   my ( $self, @messages ) = @_;
+  $log->debugf("[%s] simple_chat with %d message(s), model=%s",
+    ref $self, scalar @messages, $self->chat_model // 'default');
   my $request = $self->chat(@messages);
   my $response = $self->user_agent->request($request);
   return $request->response_call->($response);
@@ -64,8 +67,10 @@ sub simple_chat_stream {
   my ( $self, $callback, @messages ) = @_;
   croak "simple_chat_stream requires a callback as first argument"
     unless ref $callback eq 'CODE';
+  $log->debugf("[%s] simple_chat_stream (%s format)", ref $self, $self->stream_format);
   my $request = $self->chat_stream(@messages);
   my $chunks = $self->execute_streaming_request($request, $callback);
+  $log->debugf("[%s] Stream completed: %d chunks", ref $self, scalar @$chunks);
   return join('', map { $_->content } @$chunks);
 }
 
@@ -106,6 +111,7 @@ sub _build__async_http {
 
 async sub simple_chat_f {
   my ( $self, @messages ) = @_;
+  $log->debugf("[%s] simple_chat_f with %d message(s)", ref $self, scalar @messages);
   my $request = $self->chat(@messages);
 
   my $response = await $self->_async_http->do_request(
@@ -227,7 +233,7 @@ Langertha::Role::Chat - Role for APIs with normal chat functionality
 
 =head1 VERSION
 
-version 0.202
+version 0.300
 
 =head1 SYNOPSIS
 
