@@ -1,9 +1,10 @@
 package Langertha::Role::HTTP;
 # ABSTRACT: Role for HTTP APIs
-our $VERSION = '0.202';
+our $VERSION = '0.300';
 use Moose::Role;
 
 use Carp qw( croak );
+use Log::Any qw( $log );
 use URI;
 use LWP::UserAgent;
 
@@ -74,7 +75,11 @@ sub generate_http_request {
 
 sub parse_response {
   my ( $self, $response ) = @_;
-  croak "".(ref $self)." request failed: ".($response->status_line) unless $response->is_success;
+  unless ($response->is_success) {
+    $log->errorf("[%s] HTTP %s", ref $self, $response->status_line);
+    croak "".(ref $self)." request failed: ".($response->status_line);
+  }
+  $log->tracef("[%s] Response: %s", ref $self, $response->decoded_content);
   return $self->json->decode($response->decoded_content);
 }
 
@@ -141,7 +146,7 @@ Langertha::Role::HTTP - Role for HTTP APIs
 
 =head1 VERSION
 
-version 0.202
+version 0.300
 
 =head2 url
 
